uhugo.post_install.providers.__init__ — uHugo 1.1.10 documentation

# uhugo.post_install.providers.__init__

class uhugo.post_install.providers.ProviderBase(api_key: str = None, config_path: str = None, hugo_version: str = None)

  This is a base class for all the providers

  Parameters:

    - hugo_version – New Hugo version

    - api_key – Authentication key for providers

    - config_path – Path for configuration file of the provider

  current_version(project_name: str = None) → Any

    Gets the current Hugo version

    Parameters:

      project_name – Name of the project to check from

  get_projects(project_name: str = None) → Any

    Checks and gets the current project

    Parameters:

      project_name – Name of the project to update

  update_api(project_name: str) → Any

    Updates an API

    Parameters:

      project_name – Name of the project to update

    Returns:

  update_config_file(file_name: str) → Any

    Updates a configuration file

    Returns: